---
title: Ast Services
author:
date: 2022-11-23
...

# Ast Services {#ast-services}

## kernel.ast.compute (`EXEC`) {#compute}

Ensures that AST is computed


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## kernel.ast.changed (`SIGNAL`) {#changed}

Emitted when the AST has been changed


## kernel.ast.source (`DATA`) {#source}

Source file positions.


> [`source`](#source)  `::=` `{` `"dir"` `:` _string_ , `"base"` `:` _string_
  , `"file"` `:` _string_ , `"line"` `:` _number_ `}`
  

## kernel.ast.markerKind (`DATA`) {#markerkind}

Marker kind


> [`markerKind`](#markerkind)  `::=` _tags…_
  

| Tags | Value | Description |
|:-----|:------|:------------|
| Expression | `"expression"` | Expression |
| Lvalue | `"lvalue"` | Lvalue |
| Declaration | `"declaration"` | Declaration |
| Statement | `"statement"` | Statement |
| Global | `"global"` | Global |
| Term | `"term"` | Term |
| Property | `"property"` | Property |


## kernel.ast.markerKindTags (`GET`) {#markerkindtags}

Registered tags for the above type.


> _input_ `::=` _null_
  

> _output_ `::=` [`tag`](data.md#tag)  `[]`
  

## kernel.ast.markerVar (`DATA`) {#markervar}

Marker variable


> [`markerVar`](#markervar)  `::=` _tags…_
  

| Tags | Value | Description |
|:-----|:------|:------------|
| None | `"none"` | None |
| Variable | `"variable"` | Variable |
| Function | `"function"` | Function |


## kernel.ast.markerVarTags (`GET`) {#markervartags}

Registered tags for the above type.


> _input_ `::=` _null_
  

> _output_ `::=` [`tag`](data.md#tag)  `[]`
  

## kernel.ast.markerInfo (`ARRAY`) {#markerinfo}

Marker information


## kernel.ast.signalMarkerInfo (`SIGNAL`) {#signalmarkerinfo}

Signal for array [`markerInfo`](#markerinfo) 


## kernel.ast.markerInfoData (`DATA`) {#markerinfodata}

Data for array rows [`markerInfo`](#markerinfo) 


> [`markerInfoData`](#markerinfodata)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"key"` | _string_ | Entry identifier. |
| `"kind"` | [`markerKind`](ast.md#markerkind)  | Marker kind |
| `"var"` | [`markerVar`](ast.md#markervar)  | Marker variable |
| `"name"` | _string_ | Marker short name |
| `"descr"` | _string_ | Marker declaration or description |
| `"sloc"` | [`source`](ast.md#source)  | Source location |


## kernel.ast.fetchMarkerInfo (`GET`) {#fetchmarkerinfo}

Data fetcher for array [`markerInfo`](#markerinfo) 


> _input_ `::=` _number_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"pending"` | _number_ | remaining entries to be fetched |
| `"updated"` | [`markerInfoData`](ast.md#markerinfodata)  `[]` | updated entries |
| `"removed"` | _string_ `[]` | removed entries |
| `"reload"` | _boolean_ | array fully reloaded |


## kernel.ast.reloadMarkerInfo (`GET`) {#reloadmarkerinfo}

Force full reload for array [`markerInfo`](#markerinfo) 


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## kernel.ast.marker (`DATA`) {#marker}

Localizable AST markers


> [`marker`](#marker)  `::=` `#stmt` | `#decl` | `#lval` | `#expr` | `#term`
  | `#global` | `#property`
  

## kernel.ast.location (`DATA`) {#location}

Location: function and marker


> [`location`](#location)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"fct"` | `#fct` | Function |
| `"marker"` | [`marker`](ast.md#marker)  | Marker |


## kernel.ast.getMainFunction (`GET`) {#getmainfunction}

Get the current 'main' function.


> _input_ `::=` _null_
  

> _output_ `::=` `#fct` `?`
  

## kernel.ast.getFunctions (`GET`) {#getfunctions}

Collect all functions in the AST


> _input_ `::=` _null_
  

> _output_ `::=` `#fct` `[]`
  

## kernel.ast.printFunction (`GET`) {#printfunction}

Print the AST of a function


> _input_ `::=` `#fct`
  

> _output_ `::=` [`text`](data.md#text) 
  

## kernel.ast.functions (`ARRAY`) {#functions}

AST Functions


## kernel.ast.signalFunctions (`SIGNAL`) {#signalfunctions}

Signal for array [`functions`](#functions) 


## kernel.ast.functionsData (`DATA`) {#functionsdata}

Data for array rows [`functions`](#functions) 


> [`functionsData`](#functionsdata)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"key"` | `#functions` | Entry identifier. |
| `"name"` | _string_ | Name |
| `"signature"` | _string_ | Signature |
| `"main"` (opt.) | _boolean_ | Is the function the main entry point |
| `"defined"` (opt.) | _boolean_ | Is the function defined? |
| `"stdlib"` (opt.) | _boolean_ | Is the function from the Frama-C stdlib? |
| `"builtin"` (opt.) | _boolean_ | Is the function a Frama-C builtin? |
| `"sloc"` | [`source`](ast.md#source)  | Source location |


## kernel.ast.fetchFunctions (`GET`) {#fetchfunctions}

Data fetcher for array [`functions`](#functions) 


> _input_ `::=` _number_
  

> _output_ `::=` `{` _output…_ `}`
  

| Output | Format | Description |
|:-------|:------:|:------------|
| `"pending"` | _number_ | remaining entries to be fetched |
| `"updated"` | [`functionsData`](ast.md#functionsdata)  `[]` | updated entries |
| `"removed"` | `#functions` `[]` | removed entries |
| `"reload"` | _boolean_ | array fully reloaded |


## kernel.ast.reloadFunctions (`GET`) {#reloadfunctions}

Force full reload for array [`functions`](#functions) 


> _input_ `::=` _null_
  

> _output_ `::=` _null_
  

## kernel.ast.getInformationUpdate (`SIGNAL`) {#getinformationupdate}

Updated AST information


## kernel.ast.getInformation (`GET`) {#getinformation}

Get available information about markers. When no marker is given, returns all kinds of information (with empty `descr` field).


> _input_ `::=` [`marker`](ast.md#marker)  `?`
  

> _output_ `::=` `{` `"id"` `:` _string_ , `"label"` `:` _string_ , `"descr"`
  `:` _string_ , `"title"` `:` _string_ , `"text"` `:` [`text`](data.md#text)
   `}` `[]`
  

> _signals_
  

* `kernel.ast.getInformationUpdate`


## kernel.ast.getMarkerAt (`GET`) {#getmarkerat}

Returns the marker and function at a source file position, if any. Input: file path, line and column.


> _input_ `::=` `[` _string_ , _number_ , _number_ `]`
  

> _output_ `::=` `[` `#fct` `?` , [`marker`](ast.md#marker)  `?` `]`
  

## kernel.ast.getFiles (`GET`) {#getfiles}

Get the currently analyzed source file names


> _input_ `::=` _null_
  

> _output_ `::=` _string_ `[]`
  

## kernel.ast.setFiles (`SET`) {#setfiles}

Set the source file names to analyze.


> _input_ `::=` _string_ `[]`
  

> _output_ `::=` _null_
  

## kernel.ast.markerFromTermInput (`DATA`) {#markerfromterminput}

<markerFromTerm> input


> [`markerFromTermInput`](#markerfromterminput)  `::= {` _fields…_ `}`
  

| Field | Format | Description |
|:------|:------:|:------------|
| `"atStmt"` | [`marker`](ast.md#marker)  | The statement at which we will build the marker. |
| `"term"` | _string_ | The ACSL term. |


## kernel.ast.markerFromTerm (`GET`) {#markerfromterm}

Build a marker from an ACSL term.


> _input_ `::=` [`markerFromTermInput`](ast.md#markerfromterminput) 
  

> _output_ `::=` [`marker`](ast.md#marker)  `?`
  